@@ -184,7 +184,7 @@ class ReviewAssigner:
                 # care of this MR.
                 print(
                     f"INFO: {merge_request.web_url} would need review, but it "
-                    "has the '{DO_NOT_REVIEW_TAG}' tag"
+                    f"has the '{DO_NOT_REVIEW_TAG}' tag"
                 )
                 continue
             yield merge_request
